==> GotoBLAS-1.10.tar.gz: GotoBLAS/level3/syrk/syrk_beta.c <==
/*********************************************************************/
/*                                                                   */
/*             Optimized BLAS libraries                              */
/*                     By Kazushige Goto <kgoto@tacc.utexas.edu>     */
/*                                                                   */
/* Copyright (c) The University of Texas, 2005. All rights reserved. */
/* UNIVERSITY EXPRESSLY DISCLAIMS ANY AND ALL WARRANTIES CONCERNING  */
/* THIS SOFTWARE AND DOCUMENTATION, INCLUDING ANY WARRANTIES OF      */
/* MERCHANTABILITY, FITNESS FOR ANY PARTICULAR PURPOSE,              */
/* NON-INFRINGEMENT AND WARRANTIES OF PERFORMANCE, AND ANY WARRANTY  */
/* THAT MIGHT OTHERWISE ARISE FROM COURSE OF DEALING OR USAGE OF     */
/* TRADE. NO WARRANTY IS EITHER EXPRESS OR IMPLIED WITH RESPECT TO   */
/* THE USE OF THE SOFTWARE OR DOCUMENTATION.                         */
/* Under no circumstances shall University be liable for incidental, */
/* special, indirect, direct or consequential damages or loss of     */
/* profits, interruption of business, or related expenses which may  */
/* arise from use of Software or Documentation, including but not    */
/* limited to those resulting from defects in Software and/or        */
/* Documentation, or loss or inaccuracy of data of any kind.         */
/*********************************************************************/

#include <stdio.h>
#include <ctype.h>
#include "common.h"

int CNAME(long dummy1, long n,  long dummy2, FLOAT alpha,
	      FLOAT *dummy3, long dummy4, FLOAT *dummy5, long dummy6,
	      FLOAT *c, long ldc, FLOAT *buffer, long from, long to){
  long i;

#ifndef LOWER
  for (i = from; i < to; i++){
    SCAL_K(i + 1, 0, 0, alpha, c + i * ldc, 1, NULL, 0, NULL, 0);
  }
#else
  for (i = from; i < to; i++){
    SCAL_K(n - i, 0, 0, alpha, c + i * (ldc + 1), 1, NULL, 0, NULL, 0);
  }
#endif

  return 0;
}

==> GotoBLAS-1.19.tar.gz: GotoBLAS/level3/syrk/syrk_beta.c <==
/*********************************************************************/
/*                                                                   */
/*             Optimized BLAS libraries                              */
/*                     By Kazushige Goto <kgoto@tacc.utexas.edu>     */
/*                                                                   */
/* Copyright (c) The University of Texas, 2005. All rights reserved. */
/* UNIVERSITY EXPRESSLY DISCLAIMS ANY AND ALL WARRANTIES CONCERNING  */
/* THIS SOFTWARE AND DOCUMENTATION, INCLUDING ANY WARRANTIES OF      */
/* MERCHANTABILITY, FITNESS FOR ANY PARTICULAR PURPOSE,              */
/* NON-INFRINGEMENT AND WARRANTIES OF PERFORMANCE, AND ANY WARRANTY  */
/* THAT MIGHT OTHERWISE ARISE FROM COURSE OF DEALING OR USAGE OF     */
/* TRADE. NO WARRANTY IS EITHER EXPRESS OR IMPLIED WITH RESPECT TO   */
/* THE USE OF THE SOFTWARE OR DOCUMENTATION.                         */
/* Under no circumstances shall University be liable for incidental, */
/* special, indirect, direct or consequential damages or loss of     */
/* profits, interruption of business, or related expenses which may  */
/* arise from use of Software or Documentation, including but not    */
/* limited to those resulting from defects in Software and/or        */
/* Documentation, or loss or inaccuracy of data of any kind.         */
/*********************************************************************/

#include <stdio.h>
#include <ctype.h>
#include "common.h"

int CNAME(long dummy1, long n,  long dummy2, FLOAT alpha,
	  FLOAT *dummy3, long dummy4, FLOAT *dummy5, long dummy6,
	  FLOAT *c, long ldc, FLOAT *dumm7, FLOAT *dummy8,
	  long from, long to){
  long i;

#ifndef LOWER
  for (i = from; i < to; i++){
    SCAL_K(i + 1, 0, 0, alpha, c + i * ldc, 1, NULL, 0, NULL, 0);
  }
#else
  for (i = from; i < to; i++){
    SCAL_K(n - i, 0, 0, alpha, c + i * (ldc + 1), 1, NULL, 0, NULL, 0);
  }
#endif

  return 0;
}
